==> 0.0.30.tar.gz: android/src/main/kotlin/com/example/spectus_paykun/SpectusPaykunPlugin.kt <==
package com.example.spectus_paykun

import androidx.annotation.NonNull

import android.app.Activity
import android.content.Context
import android.content.Intent
import android.os.Build
import android.util.Log
import androidx.appcompat.app.AppCompatActivity
import com.app.ready.paykundemo.PayKunPayment
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry

/** SpectusPaykunPlugin */
class SpectusPaykunPlugin: FlutterPlugin, ActivityAware, MethodCallHandler, PluginRegistry.ActivityResultListener {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel
  var mActivity : AppCompatActivity? = null
  var mContext : Context? = null

    constructor()

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "spectus_paykun")
    channel.setMethodCallHandler(this)
    mContext = flutterPluginBinding.applicationContext
  }

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
        Log.e("onAttachedToActivity","Called")
        if(binding.activity == null){
            Log.e("binding.activity","null")
        }
        mActivity = binding.activity as AppCompatActivity
        binding.addActivityResultListener(this)
    }

    override fun onDetachedFromActivityForConfigChanges() {
    }

    override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
        if(binding.activity == null){
            Log.e("binding.activity","null")
        }
        mActivity = binding.activity as AppCompatActivity
    }

    override fun onDetachedFromActivity() {
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    if (call.method == "getPlatformVersion") {
      result.success("Android ${Build.VERSION.RELEASE}")
    } 
    else if (call.method == "startPayKunPayment") {

      var merchantId = call.argument<String>("merchantId")!!
      var accessToken = call.argument<String>("accessToken")!!
      var customerName = call.argument<String>("customerName")!!
      var customerEmail = call.argument<String>("customerEmail")!!
      var customerPhone = call.argument<String>("customerPhone")!!
      var productName = call.argument<String>("productName")!!
      var amount = call.argument<String>("amount")!!
      var currency = call.argument<String>("currency")!!
      var isLive = call.argument<Boolean>("isLive")!!

      if(mActivity==null){
            Log.e("Mactivity","Null")
        }

      PayKunPayment().startPayKunPayment( mActivity!!, merchantId, accessToken,
                                      customerName, customerEmail,
                                      customerPhone, productName,
                                      currency, amount, isLive,
                                      { error, transactionID, prodcutDetails ->
                                        Log.e("Callback in Dart","")
                                        if (error != null) {
                                            Log.e("Inside Error Log","")
                                            mActivity!!.runOnUiThread(Runnable {
                                                //call the methodChannel.invokeMethod here to avoid @UiThread exception
                                                result.error("1", "Array Empty", "NoDetails")
                                            })
                                        } else {
                                          mActivity!!.runOnUiThread(Runnable {
                                              //call the methodChannel.invokeMethod here to avoid @UiThread exception
                                              result.success(transactionID)
                                          })
                                        }
                                    })
    }
    else {
      result.notImplemented()
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?): Boolean {
        return false
    }
}

==> 0.0.39.tar.gz: android/src/main/kotlin/com/example/spectus_paykun/SpectusPaykunPlugin.kt <==
package com.example.spectus_paykun

import androidx.annotation.NonNull

import android.app.Activity
import android.content.Context
import android.content.Intent
import android.os.Build
import android.util.Log
import androidx.appcompat.app.AppCompatActivity
import com.app.ready.paykundemo.PayKunPayment
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry

/** SpectusPaykunPlugin */
class SpectusPaykunPlugin: FlutterPlugin, ActivityAware, MethodCallHandler, PluginRegistry.ActivityResultListener {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel
  var mActivity : AppCompatActivity? = null
    var normalActivity : Activity? = null
  var mContext : Context? = null

    constructor()

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "spectus_paykun")
    channel.setMethodCallHandler(this)
    mContext = flutterPluginBinding.applicationContext
  }

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
        Log.e("onAttachedToActivity","Called")
        if(binding.activity == null){
            Log.e("binding.activity","null")
        }
        this.normalActivity = binding.activity
        this.mActivity = binding.activity as AppCompatActivity
        binding.addActivityResultListener(this)
    }

    override fun onDetachedFromActivityForConfigChanges() {
    }

    override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
        if(binding.activity == null){
            Log.e("binding.activity","null")
        }
        this.normalActivity = binding.activity
        this.mActivity = binding.activity as AppCompatActivity
    }

    override fun onDetachedFromActivity() {
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {

        Log.e("METHOD CALL","==>> " + call.method)

    if (call.method == "getPlatformVersion") {
      result.success("Android ${Build.VERSION.RELEASE}")
    } 
    else if (call.method == "startPayKunPayment") {

      var merchantId = call.argument<String>("merchantId")!!
      var accessToken = call.argument<String>("accessToken")!!
      var customerName = call.argument<String>("customerName")!!
      var customerEmail = call.argument<String>("customerEmail")!!
      var customerPhone = call.argument<String>("customerPhone")!!
      var productName = call.argument<String>("productName")!!
      var amount = call.argument<String>("amount")!!
      var currency = call.argument<String>("currency")!!
      var isLive = call.argument<Boolean>("isLive")!!

      if(mActivity==null){
            Log.e("Mactivity","Null")
        }

        if(normalActivity==null){
            Log.e("NORMAL ACTIVITY","Null")
        }

      PayKunPayment().startPayKunPayment(this.normalActivity!!,
                                        merchantId, accessToken,
                                      customerName, customerEmail,
                                      customerPhone, productName,
                                      currency, amount, isLive,
                                      { error, transactionID, prodcutDetails ->
                                        Log.e("Callback in Dart","")
                                        if (error != null) {
                                            Log.e("Inside Error Log","")
                                            mActivity!!.runOnUiThread(Runnable {
                                                //call the methodChannel.invokeMethod here to avoid @UiThread exception
                                                result.error("1", "Array Empty", "NoDetails")
                                            })
                                        } else {
                                          mActivity!!.runOnUiThread(Runnable {
                                              //call the methodChannel.invokeMethod here to avoid @UiThread exception
                                              result.success(transactionID)
                                          })
                                        }
                                    })
    }
    else {
      result.notImplemented()
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?): Boolean {
        return false
    }
}
